Changelog
=========

0.3.0
-----

- hardware wallet support via frame
- submit signatures to transaction service
- retrieve pending transactions from transaction service
- execute signed transactions
- convert confirmations to signatures
- expanded documentation about signing

0.2.0
-----

- add support for safe contracts 1.3.0
- switch to multicall 1.3.0 call only
- support multiple networks
- autodetect transaction service from chain id
